##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 3                                                              #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################


######################################
# Section 3.1                        #
######################################
set.seed(12345)
Score <- sample(0:100, 6, replace = T)
Subject <- c("Math", "English", "Chinese", "Science", "Society", "Statistics")
names(Score) <- Subject
Score
mean(Score)
weighted.mean(Score, w = c(2, 1, 1, 2, 1, 3))
median(Score)

# Mode, Most Likely Value
set.seed(12345)
Index <- sample(0:10, 50, replace = T)
Index

# install.packages("modeest")
library(modeest)
mlv(Index)
table(Index)


# Geometric Mean
MutualFund <- read_excel("data/chap03/MutualFund.xlsx")
MutualFund
MutualFund$GrowthFactor <- 1 + MutualFund$`Return (%)`/100
MutualFund
prod(MutualFund$GrowthFactor)^{1/length(MutualFund$GrowthFactor)}

# Percentiles, Quartiles
StartingSalaries <- read_excel("data/chap03/StartingSalaries.xlsx")
StartingSalaries
Salary <- StartingSalaries$`Monthly Starting Salary ($)`
? quantile
quantile(Salary, type = 6)
quantile(Salary, probs = 0.80, type = 6)



######################################
# Section 3.2                        #
######################################
# Range
diff(range(Salary))

# IQR
IQR(Salary, type = 6)
?IQR

# Variance
var(Salary)

# Standard Deviation
sd(Salary)

# Coefficient of Variation
sd(Salary)/mean(Salary)
# install.packages("EnvStats")
library(EnvStats)
cv(Salary)



######################################
# Section 3.3                        #
######################################

# skewness
hist(Salary)
library(e1071)
skewness(Salary)

EnvStats:::skewness(Salary)
modeest:::skewness(Salary)

# z-Score
Salary.zScore <- (Salary - mean(Salary))/sd(Salary)
mean(Salary.zScore)
var(Salary.zScore)
hist(Salary)
hist(Salary.zScore)
skewness(Salary.zScore)


scale(Salary)


# Detect Outlier
Detect_Outlier <- function(x){
  # x <- mySalary
  Q1 <- quantile(x, type = 6, probs = 0.25)
  Q3 <- quantile(x, type = 6, probs = 0.75)
  IQR.x <- IQR(x, type = 6)
  Lower.Limit <- Q1 - 1.5 * IQR.x
  Upper.Limit <- Q3 + 1.5 * IQR.x
  ifelse(x < Lower.Limit | x > Upper.Limit, "Outlier", "Not")
}

Detect_Outlier(Salary)
boxplot(Salary)

mySalary <- Salary
mySalary[3] <- mySalary[3] * 10
Detect_Outlier(mySalary)
boxplot(mySalary)



######################################
# Section 3.4                        #
######################################

# Five-Number Summary
summary(Salary)

boxplot(Salary)



######################################
# Section 3.5                        #
######################################

# Covariance, Correlation Coefficient
Electronics <- read_excel("data/chap03/Electronics.xlsx")
Electronics
names(Electronics)
attach(Electronics)

cov(`No. of Commercials`, `Sales Volume`)
cor(`No. of Commercials`, `Sales Volume`)

plot(`No. of Commercials`, `Sales Volume`, main = "Scatter Diagram for the 
     San Francisco Electronics Store")
abline(h = mean(`Sales Volume`), v = mean(`No. of Commercials`), 
       lty = 2, col = "grey")
text(mean(`No. of Commercials`), max(`Sales Volume`), 
     bquote(bar(x) == .(mean(`No. of Commercials`))))
text(max(`No. of Commercials`), mean(`Sales Volume`),  
     bquote(bar(y) == .(mean(`Sales Volume`))))
detach(Electronics)

